import { PrismaClient } from "@prisma/client";

const prisma = new PrismaClient();

export const getHeroImages = async (req, res) => {
    try {
        const coaches = await prisma.heroImages.findMany();
        res.status(200).json({ status: 200, data: coaches });
    } catch (error) {
        res.status(500).json({ status: 500, message: error.message });
    }
};

export const uploadHeroImages = async (req, res) => {
    try {
        const files = req.files;
        const heroImages = files.map((file) => file.filename);
        const newHeroImages = await prisma.heroImages.create({
            data: {
                urls: heroImages,
            },
        });
        res.status(201).json({ status: 201, data: newHeroImages });
    } catch (error) {
        res.status(500).json({ status: 500, message: error.message });
    }
};

export const updateHeroImage = async (req, res) => {
    const { id, index } = req.params;
    try {
        const data = await prisma.heroImages.findUnique({where:{id: id}})
        let oldArray = data.urls
        oldArray[index] = req.file.filename
        const updatedEvent = await prisma.heroImages.update({
            where: { id: id },
            data: {
                urls: oldArray
            },
        });
        res.status(200).json({ status: 200, data: updatedEvent });
    } catch (error) {
        res.status(500).json({ status: 500, message: error.message });
    }
};

export const deleteHeroImage = async (req, res) => {
    const { id } = req.params;
    try {
        await prisma.heroImages.delete({
            where: { id: id },
        });
        res.status(200).json({
            status: 200,
            message: "Hero Image deleted successfully",
        });
    } catch (error) {
        res.status(500).json({ status: 500, message: error.message });
    }
};
